@@ -3,9 +3,34 @@ from ks_constants.devs import Developer
 from ks_constants.locale import Language
 
 
-class Team(IntEnum):
-    Survivor = 0
-    Kerrigan = 1
+from enum import Enum, EnumMeta
+
+
+class MetaEnum(EnumMeta):
+    def __contains__(cls, item):
+        try:
+            cls(item)
+        except ValueError:
+            return False
+        return True
+
+
+class BaseEnum(Enum, metaclass=MetaEnum):
+    pass
+
+class Team(Enum):
+    Survivor = (0, 8)
+    Kerrigan = (1, 2)
+
+    def __init__(self, _id: int, max_players: int):
+        self._id = _id
+        self._max_team_size = max_players
+
+    def get_max_size(self):
+        return self._max_team_size
+
+    def to_int(self):
+        return self._id
 
     @classmethod
     def from_index(cls, index):
@@ -19,7 +44,7 @@ class RoleType(Enum):
     Hunter = (3, Team.Kerrigan)
 
     def __init__(self, _id: int, team: Team):
-        self._id = id
+        self._id = _id
         self._team = team
 
     def get_team(self) -> Team:
@@ -28,7 +53,7 @@ class RoleType(Enum):
     def to_int(self):
         return self._id
 
-class Role(Enum):
+class Role(BaseEnum):
     Kerrigan = (0, RoleType.Hunter, {Language.Chinese: '凯瑞甘', Language.English: 'Kerrigan', Language.Korean: '케리건'}, Developer.geo, Developer.Luminous, True)
     Scientist = (1, RoleType.Builder, {Language.Chinese: '科学家', Language.English: 'Scientist', Language.Korean: '과학자'}, Developer.geo, Developer.Luminous, True)
     Dark_Templar = (2, RoleType.Support, {Language.Chinese: '黑暗圣堂武士', Language.English: 'Dark Templar', Language.Korean: '암흑기사'}, Developer.geo, Developer.Luminous, True)
